@@ -582,7 +582,7 @@ MAKE_GET_WITH_DEFAULT (gchar, char, );
  * Returns: the value contained in the database.
  */
 MAKE_GET_SIMPLE (gboolean, FALSE, boolean, TC_boolean, 
-		 (*(gboolean *)value->_value));
+		 (*(CORBA_boolean *)value->_value));
 
 MAKE_GET_WITH_DEFAULT (gboolean, boolean, );
 
