@@ -12,30 +12,36 @@
 #include <bonobo.h>
 
 #include "bonobo-property-editor.h"
+#include "bonobo-config-utils.h"
 
 static void
 set_value_cb (BonoboPropertyEditor *editor,
 	      BonoboArg            *value,
 	      CORBA_Environment    *ev)
 {
-	GtkWidget *l;
+	GtkWidget *e;
+	char *s;
 
-	l = bonobo_control_get_widget (BONOBO_CONTROL (editor));
+	e = GTK_BIN (editor)->child;
 
-	gtk_label_set_text (GTK_LABEL (l), "value set");
+	s = bonobo_config_any_to_string (value);
+	
+	gtk_entry_set_text (GTK_ENTRY (e), s);
+
+	g_free (s);
 }
 
-BonoboObject *
+GtkWidget *
 bonobo_property_editor_default_new ()
 {
-	GtkWidget *l;
+	GtkWidget *e;
 	BonoboPropertyEditor *ed;
 
-	l = gtk_label_new ("no value set");
-	gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
-	gtk_widget_show (l);
+	e = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY (e), "no value set");
+	gtk_entry_set_editable (GTK_ENTRY (e), FALSE);
 
-	ed = bonobo_property_editor_new (l, set_value_cb);
+	ed = bonobo_property_editor_construct (e, set_value_cb, NULL);
 
-	return BONOBO_OBJECT (ed);
+	return GTK_WIDGET (ed);
 }
